package com.gic.auth.service.outer.impl;

import java.util.ArrayList;
import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.gic.api.base.commons.ServiceResponse;
import com.gic.auth.constant.MenuLevelConstants;
import com.gic.auth.constant.MenuProjectConstants;
import com.gic.auth.constant.MenuTypeEnum;
import com.gic.auth.dto.MenuDTO;
import com.gic.auth.entity.TabSysMenu;
import com.gic.auth.qo.MenuListQO;
import com.gic.auth.service.AuthCodeApiService;
import com.gic.auth.service.MenuApiService;
import com.gic.auth.service.MenuService;
import com.gic.commons.util.EntityUtil;
import com.gic.enterprise.error.ErrorCode;
import com.gic.enterprise.utils.valid.ValidParamsUtils;

@Service("menuApiService")
public class MenuApiServiceImpl implements MenuApiService {
    @Autowired
    private MenuService menuService;
    @Autowired
    private AuthCodeApiService authCodeApiService;

    @Override
    public ServiceResponse<List<MenuDTO>> getUserMenu(Integer userId, Integer enterpriseId, Integer currentMenu) {
        MenuListQO params = new MenuListQO();
        params.setMenuType(MenuTypeEnum.PAGE.getCode());
        List<TabSysMenu> menuList = this.menuService.listMenu(params);
        int level = 1;
        int parentId = 0;
        if (currentMenu != null) {
            TabSysMenu menu = this.menuService.getMenuById(currentMenu);
            parentId = currentMenu;
            level = menu.getLevel() + 1;
        }
        return ServiceResponse.success(this.treeMenu(menuList, level, parentId));
    }

    @Override
    public ServiceResponse<List<MenuDTO>> getSuperAdminMenu(Integer userId, Integer enterpriseId) {
        return this.getUserMenu(userId, enterpriseId, null);
    }

    @Override
    public ServiceResponse<List<MenuDTO>> listMenuTree(MenuListQO params) {
        params.setMenuType(MenuTypeEnum.PAGE.getCode());
        List<TabSysMenu> menuList = this.menuService.listMenu(params);
        return ServiceResponse.success(this.treeMenu(menuList, 1, 0));
    }

    @Override
    public ServiceResponse<List<MenuDTO>> listMenuRoleByParentId(Integer parentId) {
        TabSysMenu record = menuService.getMenuById(parentId);
        if (record == null) {
            return ServiceResponse.failure(ErrorCode.PARAMETER_ERROR.getCode(), "参数有误，页面不存在");
        }
        List<TabSysMenu> menuList = menuService.listMenuRoleByParentId(parentId);
        return ServiceResponse.success(EntityUtil.changeEntityListNew(MenuDTO.class, menuList));
    }

    @Override
    public ServiceResponse<Void> saveGICPage(MenuDTO menuDTO) {
        menuDTO.setProject(MenuProjectConstants.DEFAULT_PROJECT);
        return savePage(menuDTO, MenuDTO.SavePageValid.class);
    }

    @Override
    public ServiceResponse<Void> updateGICPage(MenuDTO menuDTO) {
        return updatePage(menuDTO, MenuDTO.SavePageValid.class);
    }

    @Override
    public ServiceResponse<Void> deleteMenu(Integer menuId) {
        TabSysMenu record = menuService.getMenuById(menuId);
        if (record == null) {
            return ServiceResponse.failure(ErrorCode.PARAMETER_ERROR.getCode(), "主键参数有误，查无数据");
        }
        MenuDTO menuDTO = new MenuDTO();
        menuDTO.setMenuId(menuId);
        menuDTO.setStatus(0);
        menuService.updatePage(menuDTO);
        return ServiceResponse.success();
    }

    @Override
    public ServiceResponse<Void> saveGICChildPage(MenuDTO menuDTO) {
        menuDTO.setProject(MenuProjectConstants.DEFAULT_PROJECT);
        return saveChildPage(menuDTO, MenuDTO.SaveGICChildPageValid.class);
    }

    @Override
    public ServiceResponse<Void> updateGICChildPage(MenuDTO menuDTO) {
        return updateChildPage(menuDTO, MenuDTO.SaveGICChildPageValid.class);
    }

    @Override
    public ServiceResponse<Void> updateAppPage(MenuDTO menuDTO) {
        return updatePage(menuDTO, MenuDTO.UpdateAppPageValid.class);
    }

    @Override
    public ServiceResponse<Void> saveAppChildPage(MenuDTO menuDTO) {
        return saveChildPage(menuDTO, MenuDTO.SaveAppChildPageValid.class);
    }

    @Override
    public ServiceResponse<Void> updateAppChildPage(MenuDTO menuDTO) {
        return updateChildPage(menuDTO, MenuDTO.EditAppChildPageValid.class);
    }


    private ServiceResponse<Void> savePage(MenuDTO menuDTO, Class clazz) {
        ServiceResponse paramsValid = ValidParamsUtils.allCheckValidate(menuDTO, clazz);
        if (!paramsValid.isSuccess()) {
            return paramsValid;
        }
        //sort
        int maxSort = menuService.getMaxSortByParentId(MenuLevelConstants.FIRST_LEVEL_PARENT_ID, menuDTO.getProject());
        menuDTO.setSort(maxSort + 1);
        //level
        menuDTO.setLevel(1);

        menuDTO.setParentId(MenuLevelConstants.FIRST_LEVEL_PARENT_ID);
        menuDTO.setMenuType(MenuTypeEnum.PAGE.getCode());
        menuService.savePage(menuDTO);
        return ServiceResponse.success();
    }

    private ServiceResponse<Void> saveChildPage(MenuDTO menuDTO, Class clazz) {
        ServiceResponse paramsValid = ValidParamsUtils.allCheckValidate(menuDTO, clazz);
        if (!paramsValid.isSuccess()) {
            return paramsValid;
        }
        TabSysMenu record = menuService.getMenuById(menuDTO.getParentId());
        if (record == null) {
            return ServiceResponse.failure(ErrorCode.PARAMETER_ERROR.getCode(), "父级页面不存在");
        }
        //sort
        int maxSort = menuService.getMaxSortByParentId(menuDTO.getParentId(), menuDTO.getProject());
        menuDTO.setSort(maxSort + 1);
        //level
        menuDTO.setLevel(record.getLevel() + 1);
        //父级code
        menuDTO.setParentCode(record.getMenuCode());

        menuDTO.setMenuType(MenuTypeEnum.PAGE.getCode());
        menuService.savePage(menuDTO);
        return ServiceResponse.success();
    }

    private ServiceResponse<Void> updatePage(MenuDTO menuDTO, Class clazz) {
        TabSysMenu record = menuService.getMenuById(menuDTO.getMenuId());
        if (record == null) {
            return ServiceResponse.failure(ErrorCode.PARAMETER_ERROR.getCode(), "主键参数有误，查无数据");
        }
        ServiceResponse paramsValid = ValidParamsUtils.allCheckValidate(menuDTO, clazz);
        if (!paramsValid.isSuccess()) {
            return paramsValid;
        }
        menuService.updatePage(menuDTO);
        return ServiceResponse.success();
    }

    private ServiceResponse<Void> updateChildPage(MenuDTO menuDTO, Class clazz) {
        TabSysMenu parent = menuService.getMenuById(menuDTO.getParentId());
        if (parent == null) {
            return ServiceResponse.failure(ErrorCode.PARAMETER_ERROR.getCode(), "父级页面不存在");
        }
        menuService.updatePage(menuDTO);
        return updatePage(menuDTO, clazz);
    }

    private List<MenuDTO> treeMenu(List<TabSysMenu> menuList, int level, int parentId) {
        List<MenuDTO> list = null;
        if (level < 5) {
            for (TabSysMenu menu : menuList) {
                if (level == menu.getLevel() && menu.getIsShow().intValue() == 1
                        && menu.getParentId().intValue() == parentId) {
                    MenuDTO menuDTO = EntityUtil.changeEntityByJSON(MenuDTO.class, menu);
                    menuDTO.setChildren(this.treeMenu(menuList, menu.getLevel().intValue() + 1, menuDTO.getMenuId()));
                    if (list == null) {
                        list = new ArrayList<>();
                    }
                    list.add(menuDTO);
                }
            }
        }
        return list;
    }
}
