package com.gic.auth.web.controller;

import com.alibaba.fastjson.JSON;
import com.gic.api.base.commons.ServiceResponse;
import com.gic.auth.dto.MenuDTO;
import com.gic.auth.qo.MenuListQO;
import com.gic.auth.service.MenuApiService;
import com.gic.commons.webapi.reponse.RestResponse;
import com.gic.enterprise.response.EnterpriseRestResponse;
import com.gic.enterprise.utils.ResultControllerUtils;
import com.gic.enterprise.utils.UserDetailUtils;
import org.apache.dubbo.rpc.RpcContext;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;

@RestController
public class MenuController {
    @Autowired
    private MenuApiService menuApiService;

    @RequestMapping("login-user-menu")
    public RestResponse loginUserMenu(Integer currentMenu){
        Integer userId = UserDetailUtils.getUserDetail().getUserId();
        Integer enterpriseId = UserDetailUtils.getUserDetail().getEnterpriseId();
        System.out.println(JSON.toJSONString(RpcContext.getContext().getAttachments()));
        ServiceResponse<List<MenuDTO>> userMenu = this.menuApiService.getUserMenu(userId, enterpriseId, currentMenu);
        if(userMenu.isSuccess()){
            return RestResponse.success(userMenu.getResult());
        }
        return EnterpriseRestResponse.failure(userMenu);
    }

    /**
     * 新增GIC页面
     * @Title: saveGICPage 
     * @Description:
      * @author guojuxing
     * @param menuDTO 
     * @return  com.gic.commons.webapi.reponse.RestResponse 
      */
    @RequestMapping("/save-gic-page")
    public RestResponse saveGICPage(MenuDTO menuDTO) {
        return ResultControllerUtils.commonResult(menuApiService.saveGICPage(menuDTO));
    }

    @RequestMapping("/update-gic-page")
    public RestResponse updateGICPage(MenuDTO menuDTO) {
        return ResultControllerUtils.commonResult(menuApiService.updateGICPage(menuDTO));
    }

    @RequestMapping("/delete-menu")
    public RestResponse deleteMenu(Integer menuId) {
        return ResultControllerUtils.commonResult(menuApiService.deleteMenu(menuId));
    }
    /**
     * 新增gic子页面
     * @Title: saveGICChildPage 
     * @Description:
      * @author guojuxing
     * @param menuDTO 
     * @return  com.gic.commons.webapi.reponse.RestResponse 
      */
    @RequestMapping("/save-gic-child-page")
    public RestResponse saveGICChildPage(MenuDTO menuDTO) {
        return ResultControllerUtils.commonResult(menuApiService.saveGICChildPage(menuDTO));
    }
    @RequestMapping("/update-gic-child-page")
    public RestResponse updateGICChildPage(MenuDTO menuDTO) {
        return ResultControllerUtils.commonResult(menuApiService.updateGICChildPage(menuDTO));
    }

    /**
     * 编辑应用页面
     * @Title: updateAppPage 
     * @Description:
      * @author guojuxing
     * @param menuDTO 
     * @return  com.gic.commons.webapi.reponse.RestResponse 
      */
    @RequestMapping("/update-app-page")
    public RestResponse updateAppPage(MenuDTO menuDTO) {
        return ResultControllerUtils.commonResult(menuApiService.updateAppPage(menuDTO));
    }

    /**
     * 查询列表数据
     * @Title: updateAppPage 
     * @Description:
      * @author guojuxing
     * @param params 
     * @return  com.gic.commons.webapi.reponse.RestResponse 
      */
    @RequestMapping("/list-menu-tree")
    public RestResponse listMenuTree(MenuListQO params) {
        return ResultControllerUtils.commonResult(menuApiService.listMenuTree(params));
    }
    /**
     * 查询页面下面的权限项列表数据
     * @Title: listMenuRole 
     * @Description:
      * @author guojuxing
     * @param parentId 
     * @return  com.gic.commons.webapi.reponse.RestResponse 
      */
    @RequestMapping("/list-menu-role")
    public RestResponse listMenuRole(Integer parentId) {
        return ResultControllerUtils.commonResult(menuApiService.listMenuRoleByParentId(parentId));
    }
}
